C ----------------------------------------------------------------------
C     WOLFRAM RUEHAAK, 05/07/16
C     THE ALGORITHM IS BASED ON THE CALCULATIONS OF A. WOLF.
C     
C     PURPOSE IS TO FIND THE POINT 'E' WERE THE LINE DEFINED BY POINT 'F' AND 'G' 
C     INTERSECTS WITH THE PLANE DEFINED BY THE POINTS 'A', 'B', 'D'.
C     THE PLANE CAN BE DESCRIBED WITH:
C     S = VEC(A) + C(1) * VEC(AB) + C(2) * VEC(AD)
C     THE LINE CAN BE DESCRIBED WITH:
C     k = VEC(F) + C(3) * VEC(FG)
C     THE INTERSECTION IS DEFINED BY S = K, THEREFORE FOLLOWS:
C     C(1)*VEC(AB)+C(2)*VEC(AD)+C(3)*VEC(FG) = VEC(F)-VEC(A)
C                                      _      _
C                                     |  C(1) |
C     [VEC(AB) | VEC(AD) | VEC(FG)] * |  C(2) | = VEC(F) - VEC(A)
C                                     |_ C(3)_|
C
C     THIS RESULTS IN THE FOLLOWING MATRICE VECTOR PRODUKT:
C     _                                    _    _    _     _            _
C    | (b_x - a_x) (d_x - a_x) (g_x - f_x) |   | c_1 |    | (f_x - a_x) |
C    | (b_y - a_y) (d_y - a_y) (g_y - f_y) | * | c_2 | =  | (f_y - a_y) |
C    |_(b_z - a_z) (d_z - a_z) (g_z - f_z)_|   |_c_3_|    |_(f_z - a_z)_|
C    
C     THIS CAN BE SOLVED FOR INSTANCE FOR c_3.
C
C     THE COORDINATES OF THE POINT E WE ARE LOOKING FOR IS:
C      VEC(E) = VEC(F) + c_3 *VEC(FG) = VEC(D) * VEC(E) = 
C     _    _          _            _
C    | f_x |         | (g_x - f_x) |
C    | f_x | - c_3 * | (g_x - f_x) |
C    |_f_x_|         |_(g_x - f_x)_|
C
C    THIS LINEAR EQUATION COULD BE SOLVED EIGTHER DIRECTLY (GAUSS-ELIMINATION) 
C    OR WITH THE HELP OF AN EQUATION SOLVER WICH I HAVE DONE (SORRY).
C    I USE THE LAPACK ROUTINE DGESVX.
C
C     C O M P I L I N G:
C     WITH THE INTEL FORTRAN COMPILER ON LINUX AND PROPERLY 
C     INSTALLED LAPACK A COMMAND LIKE:
C
C     $ifort -o plints.x -llapack -lblas -lg2c -FI plintsc.f90 callplis.f90
C
C     SHOULD WORK.
C ----------------------------------------------------------------------
C
      PROGRAM PLINTSC
      
      IMPLICIT NONE
      
      INTEGER I, J, K   
      INTEGER     NI,NJ,NK
      PARAMETER(  NI = 3,NJ = 3,NK = 1)
      DOUBLE PRECISION AM(NI,NJ)
      DOUBLE PRECISION BM(NI,NK)
      DOUBLE PRECISION C(NI,NK)
      DOUBLE PRECISION A(NI),B(NI),D(NI),E(NI),F(NI),G(NI)

! LINE POINT 1
      F(1) = 10.D0
      F(2) = 10.D0
      F(3) = 10.D0

! LINE POINT 2      
      G(1) = 100.D0
      G(2) = 10.D0
      G(3) = 10.D0

! PLANE POINT 1
      A(1) = 200.D0
      A(2) = 0.D0
      A(3) = 0.D0
! PLANE POINT 2
      B(1) = 200.D0
      B(2) = 0.D0
      B(3) = 100.D0     
! PLANE POINT 3
      D(1) = 200.D0
      D(2) = 100.D0
      D(3) = 0.D0


      J = 1
      DO I = 1, NI
      AM(I,J) = B(I)-A(I)
      ENDDO
      J = 2
      DO I = 1, NI
      AM(I,J) = D(I)-A(I)
      ENDDO
      J = 3
      DO I = 1, NI
      AM(I,J) = G(I)-F(I)
      ENDDO      

      J = 1
      DO I = 1, NI
      BM(I,J) = F(I)-A(I)
      ENDDO      
C
C **********************************************************************
C
      CALL CALLPLIS(AM,BM,C)
C
C **********************************************************************
C
      DO I = 1, NI
      DO K = 1, NK
      WRITE(*,*)I,K,' C: ', C(I,K)
      ENDDO
      ENDDO
      WRITE(*,*) 'SOLUTION:'
      
      DO I = 1, NI
      E(I) = F(I)-(C(3,1)*(G(I)-F(I)))
      WRITE(*,*) E(I)
      ENDDO
      
      END
